# luxsci.ContentLibraryApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_content_library_directory**](ContentLibraryApi.md#create_content_library_directory) | **PUT** /user/{username}/content_library/{directory} | 
[**delete_content_library_directory**](ContentLibraryApi.md#delete_content_library_directory) | **DELETE** /user/{username}/content_library/{directory} | 
[**delete_content_library_file**](ContentLibraryApi.md#delete_content_library_file) | **DELETE** /user/{username}/content_library/{file_path} | 
[**get_content_library_directory**](ContentLibraryApi.md#get_content_library_directory) | **GET** /user/{username}/content_library/{directory} | 
[**get_content_library_file**](ContentLibraryApi.md#get_content_library_file) | **GET** /user/{username}/content_library/{file_path} | 
[**upload_content_library_file**](ContentLibraryApi.md#upload_content_library_file) | **PUT** /user/{username}/content_library/{file_path} | 

# **create_content_library_directory**
> InlineResponse201 create_content_library_directory(username, directory)



Create a new Content Library directory.  {{ACL: User Email: Content Library}}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.ContentLibraryApi

username = 'username_example' # str | 
directory = 'directory_example' # str | Starting with the / following /content_library, this is the directory in {username} to create. This directory must not exist and, if it is a subdirectory, the parent directories must all exist.

try:
    api_response = api_instance.create_content_library_directory(username, directory)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ContentLibraryApi->create_content_library_directory: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **str**|  | 
 **directory** | **str**| Starting with the / following /content_library, this is the directory in {username} to create. This directory must not exist and, if it is a subdirectory, the parent directories must all exist. | 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete_content_library_directory**
> InlineResponse201 delete_content_library_directory(username, directory)



Delete an empty Content Library directory.  {{ACL: User Email: Content Library}}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.ContentLibraryApi

username = 'username_example' # str | 
directory = 'directory_example' # str | Starting with the / following /content_library, this is the directory in {username} to create. This directory must not exist and, if it is a subdirectory, the parent directories must all exist.

try:
    api_response = api_instance.delete_content_library_directory(username, directory)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ContentLibraryApi->delete_content_library_directory: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **str**|  | 
 **directory** | **str**| Starting with the / following /content_library, this is the directory in {username} to create. This directory must not exist and, if it is a subdirectory, the parent directories must all exist. | 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete_content_library_file**
> InlineResponse201 delete_content_library_file(username, file_path)



Delete a file.  {{ACL: User Email: Content Library}}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.ContentLibraryApi

username = 'username_example' # str | 
file_path = 'file_path_example' # str | Required. Starting with the / following /content_library, this is the path of the file in {username} to delete.  The path must not end in a training slash. Be sure to not use double slashes.  Example: \"/files/media/image.jpg\".

try:
    api_response = api_instance.delete_content_library_file(username, file_path)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ContentLibraryApi->delete_content_library_file: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **str**|  | 
 **file_path** | **str**| Required. Starting with the / following /content_library, this is the path of the file in {username} to delete.  The path must not end in a training slash. Be sure to not use double slashes.  Example: \&quot;/files/media/image.jpg\&quot;. | 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_content_library_directory**
> InlineResponse20045 get_content_library_directory(username, directory)



Retrieve details about the specific Content Library directory. {{ACL: User Email: Content Library}}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.ContentLibraryApi

username = 'username_example' # str | 
directory = 'directory_example' # str | Starting with the / following /content_library, this is the directory in {username} to examine.  The path must end in a training slash. Be sure to not use double slashes.  Note, for example, that for directory \"/files/media/\" you would insert \"files/media/\" in this variable. If this value is omitted, the contents of the top-level directory will be returned.

try:
    api_response = api_instance.get_content_library_directory(username, directory)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ContentLibraryApi->get_content_library_directory: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **str**|  | 
 **directory** | **str**| Starting with the / following /content_library, this is the directory in {username} to examine.  The path must end in a training slash. Be sure to not use double slashes.  Note, for example, that for directory \&quot;/files/media/\&quot; you would insert \&quot;files/media/\&quot; in this variable. If this value is omitted, the contents of the top-level directory will be returned. | 

### Return type

[**InlineResponse20045**](InlineResponse20045.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_content_library_file**
> InlineResponse20046 get_content_library_file(username, file_path)



Retrieve details about the specific Content Library file.  {{ACL: User Email: Content Library}}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.ContentLibraryApi

username = 'username_example' # str | 
file_path = 'file_path_example' # str | Required. Starting with the / following /content_library, this is the path of the file in {username}.  The path must not end in a training slash. Be sure to not use double slashes.  Example: \"/files/media/image.jpg\".

try:
    api_response = api_instance.get_content_library_file(username, file_path)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ContentLibraryApi->get_content_library_file: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **str**|  | 
 **file_path** | **str**| Required. Starting with the / following /content_library, this is the path of the file in {username}.  The path must not end in a training slash. Be sure to not use double slashes.  Example: \&quot;/files/media/image.jpg\&quot;. | 

### Return type

[**InlineResponse20046**](InlineResponse20046.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **upload_content_library_file**
> InlineResponse20046 upload_content_library_file(username, file_path, body=body)



Upload a new file to the Content Library.  {{ACL: User Email: Content Library}}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.ContentLibraryApi

username = 'username_example' # str | 
file_path = 'file_path_example' # str | Required. Starting with the / following /content_library, this is the path in {username} to place the file.  The path must not end in a training slash. Be sure to not use double slashes. Example: \"files/media/image.jpg\".
body = luxsci.ContentLibraryFilePathBody() # ContentLibraryFilePathBody |  (optional)

try:
    api_response = api_instance.upload_content_library_file(username, file_path, body=body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ContentLibraryApi->upload_content_library_file: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **str**|  | 
 **file_path** | **str**| Required. Starting with the / following /content_library, this is the path in {username} to place the file.  The path must not end in a training slash. Be sure to not use double slashes. Example: \&quot;files/media/image.jpg\&quot;. | 
 **body** | [**ContentLibraryFilePathBody**](ContentLibraryFilePathBody.md)|  | [optional] 

### Return type

[**InlineResponse20046**](InlineResponse20046.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

