# luxsci.EmailAliasesApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_alias**](EmailAliasesApi.md#create_alias) | **POST** /account/{accountId}/aliases | 
[**delete_alias**](EmailAliasesApi.md#delete_alias) | **DELETE** /account/{accountId}/aliases/{aliasAddress} | 
[**get_alias_details**](EmailAliasesApi.md#get_alias_details) | **GET** /account/{accountId}/aliases/{aliasAddress} | 
[**get_aliases_report**](EmailAliasesApi.md#get_aliases_report) | **GET** /account/{accountId}/aliases | 
[**update_alias**](EmailAliasesApi.md#update_alias) | **PUT** /account/{accountId}/aliases/{aliasAddress} | 

# **create_alias**
> InlineResponse20064 create_alias(account_id, body=body)



Create new alias(es) in your account.  Your API Interface looks to see how many aliases were added to your account in the past 24 hours. If this number is equal or greater than your API create limit, then your API will reject additional alias creation requests until that situation changes. See your API Interface configuration page for your alias creation limit.  Note also that accounts are limited in the maximum number of email aliases permitted per domain. By default, this is 100 + 10 aliases per user in the domain. So, for a domain with 20 users, this would be 100 + 10x20 = 300 aliases. {{ACL: Account: Email Aliases - Manage}}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.EmailAliasesApi

account_id = 'account_id_example' # str | 
body = luxsci.AccountIdAliasesBody() # AccountIdAliasesBody | The Request body contains the following settings for new email aliases. While you can add multiple aliases at once, you should not have duplicates in your list. (optional)

try:
    api_response = api_instance.create_alias(account_id, body=body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling EmailAliasesApi->create_alias: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **str**|  | 
 **body** | [**AccountIdAliasesBody**](AccountIdAliasesBody.md)| The Request body contains the following settings for new email aliases. While you can add multiple aliases at once, you should not have duplicates in your list. | [optional] 

### Return type

[**InlineResponse20064**](InlineResponse20064.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete_alias**
> InlineResponse201 delete_alias(account_id, alias_address)



Remove an alias with the specified alias email address from your account. {{ACL: Account: Email Aliases - Manage}}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.EmailAliasesApi

account_id = 'account_id_example' # str | 
alias_address = 'alias_address_example' # str | 

try:
    api_response = api_instance.delete_alias(account_id, alias_address)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling EmailAliasesApi->delete_alias: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **str**|  | 
 **alias_address** | **str**|  | 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_alias_details**
> InlineResponse20065 get_alias_details(account_id, alias_address)



Get information about a specific email alias. {{ACL: Account: Email Aliases - Manage}}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.EmailAliasesApi

account_id = 'account_id_example' # str | 
alias_address = 'alias_address_example' # str | 

try:
    api_response = api_instance.get_alias_details(account_id, alias_address)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling EmailAliasesApi->get_alias_details: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **str**|  | 
 **alias_address** | **str**|  | 

### Return type

[**InlineResponse20065**](InlineResponse20065.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_aliases_report**
> InlineResponse20063 get_aliases_report(account_id)



Get information about your email aliases including regular aliases user forwards, domain catchalls, and WebAide Group distribution lists. {{ACL: Account: Email Aliases - Manage}}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.EmailAliasesApi

account_id = 'account_id_example' # str | 

try:
    api_response = api_instance.get_aliases_report(account_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling EmailAliasesApi->get_aliases_report: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **str**|  | 

### Return type

[**InlineResponse20063**](InlineResponse20063.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update_alias**
> InlineResponse201 update_alias(account_id, alias_address, body=body)



Modify an existing alias in your account.  This function allows you to modify regular email aliases in your account. It does not permit modification of “catch all” aliases, “user forwards,” and system aliases such as WebAide Group Distribution Lists. You can use this function to enable and disable aliases; however, you must use a separate API call to actually delete them. {{ACL: Account: Email Aliases - Manage}}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.EmailAliasesApi

account_id = 'account_id_example' # str | 
alias_address = 'alias_address_example' # str | 
body = luxsci.AliasesAliasAddressBody() # AliasesAliasAddressBody | The Request body contains the following settings for updating an email alias. (optional)

try:
    api_response = api_instance.update_alias(account_id, alias_address, body=body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling EmailAliasesApi->update_alias: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **str**|  | 
 **alias_address** | **str**|  | 
 **body** | [**AliasesAliasAddressBody**](AliasesAliasAddressBody.md)| The Request body contains the following settings for updating an email alias. | [optional] 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

